==> nextcloud-14.0.13.zip: nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "File MIME type" : "Datei MIME-Typ",
    "is" : "ist",
    "is not" : "ist nicht",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "File name" : "Dateiname",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "File system tag" : "Dateisystem-Schlagwort",
    "is tagged with" : "hat das Schlagwort",
    "is not tagged with" : "ist nicht verschlagwortet mit",
    "Select tag…" : "Wählen Sie ein Schlagwort…",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wählen Sie die Zeitzone…",
    "Request URL" : "Anfrage-URL",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Request user agent" : "User-Agent",
    "Sync clients" : "Sync-Clients",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von",
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Save" : "Speichern",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Schlagwort-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Tag management" : "Schlagwortverwaltung",
    "Files workflow engine" : "Datei-Arbeitsablauf-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…",
    "Workflow" : "Arbeitsablauf"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0.zip: nextcloud/apps/workflowengine/l10n/de_DE.js <==
OC.L10N.register(
    "workflowengine",
    {
    "Short rule description" : "Kurze Regelbeschreibung",
    "Add rule" : "Regel hinzufügen",
    "Reset" : "Zurücksetzen",
    "Save" : "Speichern",
    "Saving…" : "Speichern…",
    "Group list is empty" : "Gruppenliste ist leer",
    "Unable to retrieve the group list" : "Gruppenliste konnte nicht empfangen werden",
    "Saved" : "Gespeichert",
    "Saving failed:" : "Speichern fehlgeschlagen:",
    "Add rule group" : "Regelgruppe hinzufügen",
    "File MIME type" : "Datei MIME-Typ",
    "is" : "ist",
    "is not" : "ist nicht",
    "matches" : "entspricht",
    "does not match" : "entspricht nicht",
    "Example: {placeholder}" : "Beispiel: {placeholder}",
    "File name" : "Dateiname",
    "File size (upload)" : "Dateigröße (beim Hochladen)",
    "less" : "weniger",
    "less or equals" : "weniger oder gleich",
    "greater or equals" : "größer oder gleich",
    "greater" : "größer",
    "File system tag" : "Dateisystem-Tag",
    "is tagged with" : "hat den Tag",
    "is not tagged with" : "hat nicht den Tag",
    "Select tag…" : "Wählen Sie einen Tag…",
    "Request remote address" : "IP Adresse der Anfrage",
    "matches IPv4" : "entspricht IPv4",
    "does not match IPv4" : "entspricht nicht IPv4",
    "matches IPv6" : "entspricht IPv6",
    "does not match IPv6" : "entspricht nicht IPv6",
    "Request time" : "Anfrage-Zeitpunkt",
    "between" : "zwischen",
    "not between" : "nicht zwischen",
    "Start" : "Start",
    "End" : "Ende",
    "Select timezone…" : "Wählen Sie die Zeitzone…",
    "Request URL" : "Anfrage-URL",
    "Predefined URLs" : "Vordefinierte URLs",
    "Files WebDAV" : "WebDAV für Dateien",
    "Request user agent" : "User-Agent",
    "Sync clients" : "Sync-Clients",
    "Android client" : "Android-Client",
    "iOS client" : "iOS-Client",
    "Desktop client" : "Desktop-Client",
    "Thunderbird & Outlook addons" : "Thunderbird & Outlook addons",
    "User group membership" : "Benutzergruppen-Mitgliedschaft",
    "is member of" : "Ist Mitglied von",
    "is not member of" : "Ist kein Mitglied von",
    "The given operator is invalid" : "Der angegebene Operator ist falsch",
    "The given regular expression is invalid" : "Der angegebene reguläre Ausdruck ist falsch",
    "The given file size is invalid" : "Die angegebene Dateigröße ist ungültig",
    "The given tag id is invalid" : "Die angegebene Tag-ID ist ungültig",
    "The given IP range is invalid" : "Der angegebene IP-Bereich ist falsch",
    "The given IP range is not valid for IPv4" : "Der angegebene IP-Bereich ist für IPv4 ungültig",
    "The given IP range is not valid for IPv6" : "Der angegebene IP-Bereich ist für IPv6 ungültig",
    "The given time span is invalid" : "Die angegebene Zeitspanne ist ungültig",
    "The given start time is invalid" : "Die angegebene Startzeit ist ungültig",
    "The given end time is invalid" : "Die angegebene Endzeit ist ungültig",
    "The given group does not exist" : "Die angegebene Gruppe existiert nicht",
    "Check %s is invalid or does not exist" : "Die Prüfung %s ist ungültig ist oder nicht existiert",
    "Operation #%s does not exist" : "Operation #%s existiert nicht",
    "Operation %s does not exist" : "Operation %s existiert nicht",
    "Operation %s is invalid" : "Operation %s ist ungültig",
    "Check %s does not exist" : "Die Prüfung %s existiert nicht",
    "Check %s is invalid" : "Die Prüfung %s ist ungültig",
    "Check #%s does not exist" : "Die Prüfung #%s existiert nicht",
    "Workflow" : "Workflow",
    "Files workflow engine" : "Datei-Workflow-Engine",
    "Open documentation" : "Dokumentation öffnen",
    "Loading…" : "Laden…"
},
"nplurals=2; plural=(n != 1);");
